pub trait GetProcessor<T: FftNum, InElem>: MaybeSendwhere
InElem: GetProcessor<T, InElem>,{
// Required method
fn get_processor() -> impl Processor<T, InElem>;
}Expand description
Trait for types that can provide a processor instance.
This trait is implemented for real and complex numeric types, allowing them to automatically select the appropriate FFT processor implementation.
Required Methods
Sourcefn get_processor() -> impl Processor<T, InElem>
fn get_processor() -> impl Processor<T, InElem>
Returns a serial processor instance appropriate for this type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".